@@ -10,12 +10,11 @@ exports.nodeunit = {
     test.done();
   },
   fail: function(test) {
-    test.expect(3);
+    test.expect(2);
     grunt.util.spawn({
       grunt: true,
       args: ['test:fail', '--no-color']
     }, function(err, result) {
-      test.ok(result.stdout.indexOf('Operator:') !== -1, 'Operator should display for multiline.');
       test.ok(result.stdout.indexOf('Message: this value should be truthy') !== -1, 'Message should have been displayed.');
       test.ok(result.stdout.indexOf('Error: undefined == true') !== -1, 'Error should have been displayed.');
       test.done();
